@@ -7,7 +7,12 @@ sub new {
 
 sub MessageBody {
     my $self = shift;
-    return $self->{MessageBody};
+    return $self->{Body};
+}
+
+sub MD5OfBody {
+    my $self = shift;
+    return $self->{MD5OfBody};
 }
 
 sub MessageId {
@@ -15,6 +20,11 @@ sub MessageId {
     return $self->{MessageId};
 }
 
+sub ReceiptHandle {
+    my $self = shift;
+    return $self->{ReceiptHandle};
+}
+
 1;
 
 __END__
@@ -42,11 +52,19 @@ Get the message body.
 
 Get the message unique identifier
 
+=item B<MD5OfBody()>
+
+Get the MD5 checksum of the message body
+
+=item B<ReceiptHandle()>
+
+Get the receipt handle for the message (used as an argument to DeleteMessage)
+
 =back
 
 =head1 AUTHOR
 
-Copyright 2007 Simon Whitaker E<lt>swhitaker@cpan.orgE<gt>
+Copyright 2007-2008 Simon Whitaker E<lt>swhitaker@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
